@@ -1,5 +1,7 @@
 <?php
 
+define('SM_PATH', '../../');
+
 function squirrelmail_plugin_init_vkeyboard()
 {
     global $squirrelmail_plugin_hooks;
@@ -18,7 +20,7 @@ function plugin_vkeyboard_top()
 
 function plugin_vkeyboard_form()
 {
-    include_once 'config.php';
+    include_once(SM_PATH . 'plugins/vkeyboard/config.php');
     global $password_form_name;
 
     if($msg_font_size == 'small')
